---
title: "new JSZip() or JSZip()"
layout: default
section: api
---

__Description__ : Create a new JSZip instance.

__Arguments__ : None

__Returns__ : A new JSZip.

__Throws__ : Nothing.

<!-- __Complexity__ : Object creation in **O(1)**. -->

__Example__

```js
var zip = new JSZip();
// same as
var zip = JSZip();
```
